@@ -2,7 +2,7 @@
 
 # Notification Center code borrowed from https://github.com/maranas/pyNotificationCenter/blob/master/pyNotificationCenter.py
 
-VERSION =   '1.3.1'
+VERSION =   '1.3.2'
 
 import os, sys, json, re, hashlib, argparse, urllib, time, base64, ConfigParser, gzip, mimetypes, zipfile
 from xml.dom import minidom
@@ -14,6 +14,7 @@ warnings.filterwarnings('ignore')
 DEFAULT_COLOR   =   '\033[0;0m'
 ERROR_COLOR     =   '\033[01;31m'
 ALERT_COLOR     =   '\033[01;33m'
+OK_COLOR        =   '\033[92m'
 
 def alert(text, error_code = None, color = None):
     if error_code is not None:
@@ -69,8 +70,8 @@ if notifications:
     except objc.nosuchclass_error:
         notifications   =   False
         
-def notify(env, text):
-    alert(text)
+def notify(env, text, error_code = None, color = None):
+    alert(text, error_code, color)
     if notifications:
         notification    =   NSUserNotification.alloc().init()
         notification.setTitle_('d3ploy')
@@ -102,6 +103,7 @@ parser.add_argument('-v', '--version', help = "Print the script version and exit
 parser.add_argument('-z', '--gzip', help = "gzip files before uploading", action = "store_true", default = False)
 parser.add_argument('--confirm', help = "Confirm each file before deleting. Only works when --delete is set.", action = "store_true", default = False)
 parser.add_argument('--charset', help = "The charset header to add to text files", default = False)
+parser.add_argument('--gitignore', help = "Add .gitignore rules to the exclude list", action = "store_true", default = False)
 parser.add_argument('-c', '--config', help = "path to config file. Defaults to deploy.json in current directory", type = str, default = "deploy.json")
 args            =   parser.parse_args()
 
@@ -178,6 +180,13 @@ def upload_files(env, config):
     bucket_path         =   config.get('bucket_path', '/')
     excludes            =   config.get('exclude', [])
     svc_directories     =   ['.git', '.svn']
+    if args.gitignore or config.get('gitignore', False):
+        if os.path.exists('.gitignore'):
+            gitignore   =   open('.gitignore', 'r')
+            for line in gitignore.readlines():
+                excludes.append(line.strip())
+        else:
+            alert("--gitignore option set, but .gitignore file was not found", color = ALERT_COLOR)
 
     if type(excludes) == str or type(excludes) == unicode:
         excludes        =   [excludes]
@@ -269,7 +278,7 @@ def upload_files(env, config):
                     alert('Skipping removal of %s/%s' % (bucket, key.name.lstrip('/')))
         
     verb    =   "would be" if args.dry_run else "were"
-    notify(args.environment, "%d files %s updated" % (updated, verb))
+    notify(args.environment, "%d files %s updated" % (updated, verb), color = OK_COLOR)
     if args.delete or config.get('delete', False):
         notify(args.environment, "%d files %s removed" % (deleted, verb))
     alert("")
